Skip to contents

check_mdrb() returns a boolean indicating whether a suitable version of the metabodeconplus Rust backend mdrb is currently installed. The Rust backend is entirely optional; metabodeconplus's pure-R backend is the default and always available.

Usage

check_mdrb(stop_on_fail = FALSE)

Arguments

stop_on_fail

If TRUE, an error is thrown if the check fails, providing instructions on how to install mdrb.

Value

check_mdrb() returns TRUE if a suitable version of mdrb is installed, else FALSE.

Author

2024-2025 Tobias Schmidt: initial version.

Examples

check_mdrb()
#> [1] TRUE