check_mdrb() returns a boolean indicating whether a suitable version of the
metabodeconplus Rust backend mdrb is
currently installed. The Rust backend is entirely optional; metabodeconplus's
pure-R backend is the default and always available.
check_mdrb() returns a boolean indicating whether a suitable version of the
metabodeconplus Rust backend mdrb is
currently installed. The Rust backend is entirely optional; metabodeconplus's
pure-R backend is the default and always available.